@@ -56,14 +56,17 @@ def sqlalchemy_paging(Query, limit_number, offset_number):
 
 
 def query_set_to_dict(obj):
-    obj_dict = {}
-    for column in obj.__table__.columns.keys():
-        if hasattr(obj, column):
-            val = getattr(obj, column)
-            if isinstance(val, Decimal):
-                val = float(val)
-            obj_dict[column] = val
-    return obj_dict
+    if hasattr(obj, "__table__"):
+        obj_dict = {}
+        for column in obj.__table__.columns.keys():
+            if hasattr(obj, column):
+                val = getattr(obj, column)
+                if isinstance(val, Decimal):
+                    val = float(val)
+                obj_dict[column] = val
+        return obj_dict
+    else:
+        return dict(obj)
 
 
 def query_set_to_list(query_set):
