@@ -128,7 +128,7 @@ def es_condition_by_range(bool_must_list, column, date_list, is_contain_end_date
 
 def es_condition_by_terms(bool_must_list, column, param_list, is_need_decrypt_oralce=False):
     if param_list:
-        param_list = list(filter(None, param_list))
+        param_list = [i for i in param_list if i not in [None, "", "all"]]
         if is_need_decrypt_oralce:
             for index, id in enumerate(param_list):
                 try:
@@ -233,24 +233,27 @@ def format_bool_must_and_must_not(bool_must_list, bool_must_not_more_list):
             })
 
 
-def parse_es_sort_list(column, order):
-    if order == "asc":
-        sort_list = [
-            {
-                column: {
-                    "order": order,
-                    "missing": "_last"
+def parse_es_sort_list(column=None, order=None):
+    if column and order:
+        if order == "asc":
+            sort_list = [
+                {
+                    column: {
+                        "order": order,
+                        "missing": "_last"
+                    }
                 }
-            }
-        ]
+            ]
+        else:
+            sort_list = [
+                {
+                    column: {
+                        "order": order,
+                        "missing": "_last"
+                    }
+                }
+            ]
     else:
-        sort_list = [
-            {
-                column: {
-                    "order": order,
-                    "missing": "_last"
-                }
-            }
-        ]
+        sort_list = []
 
     return sort_list
